/*
  Author: Dumitru Brigalda

  This example shows how to create a file that stores the number of the board resets.
  The circuit:
   SD card attached to SPI bus as follows:
 ** MOSI - pin 11
 ** MISO - pin 12
 ** CLK  - pin 13
 ** CS   - pin 4
*/
#include <SPI.h>
#include <SD.h>

/* Set to 1 in order to delete the file for a fresh start */
#define DELETE_FILE 0

/* Set the file name */
#define FILE_NAME "contor.txt"

void setup(void)
{
  File myFile;
  int resetCount = 0;
  char buf[100]  = {0};
  bool success   = true;
  
  // Open serial communications and wait for port to open:
  Serial.begin(9600);
  while (!Serial) {
    ; // wait for serial port to connect. Needed for native USB port only
  }

  delay(500);

  // Initialize the SD Card
  if (success)
  {
    if (!SD.begin(4))
    {
      Serial.println("SD Card initialization failed!");
      success = false;
    }
    Serial.println("SD Card initialization done.");
  }

#if DELETE_FILE == 1
  /* If you want, delete the file for a fresh start
   * Set DELETE_FILE to 1, reset the board, let it delete the file
   * and then set back the DELETE_FILE to 0 */
  if (success)
  {
    if (SD.exists(FILE_NAME))
    {
      SD.remove(FILE_NAME);
      Serial.println("File deleted. Set DELETE_FILE to 0");
    }
    else
    {
      Serial.println("Nothing to delete. Set DELETE_FILE to 0");
    }
    Serial.println("No further actions.");

    success = false;
  }
#endif

  // Create a default file (if the file does not already exist)
  if (success)
  {
    if (!SD.exists(FILE_NAME))
    {
      // Create a default file
      Serial.println("Creating default file...");
      
      myFile = SD.open(FILE_NAME, FILE_WRITE);
      if (myFile)
      {
        myFile.print("0");
        myFile.close();
      }
      else 
      {
        Serial.println("Failed to create default file");
        success = false;
      }
    }
    else
    {
      Serial.println("File exists.");
    }
    
  }

  // Read the last saved value in the file
  if (success)
  {
    myFile = SD.open(FILE_NAME, FILE_READ);
    if (myFile)
    {
      myFile.read(buf, 100);
      myFile.close();
      resetCount = atoi(buf);
      Serial.print("Last saved reset value is ");
      Serial.println(resetCount);
    }
    else
    {
      success = false;
    }
  }

  // Delete the outdated file
  if (success)
  {
    Serial.println("Deleting the outdated file.");
    SD.remove(FILE_NAME);
  }

  // Write the new reset value in the file
  if (success)
  {
    myFile = SD.open(FILE_NAME, FILE_WRITE);
    if (myFile)
    {
      resetCount++;
      myFile.print(String(resetCount));
      myFile.close();
    }
    else 
    {
      Serial.println("Failed to update the file");
      success = false;
    }
  }

  if (success)
  {
    Serial.print("All done. Number of resets is: ");
    Serial.println(resetCount);
  }

  Serial.println();
  
}

void loop() {
  // nothing happens after setup finishes.
}
